@@ -3,7 +3,7 @@ use std::string::FromUtf8Error;
 use thiserror::Error;
 
 use cosmwasm_std::StdError;
-use cw0::PaymentError;
+use cw_utils::PaymentError;
 
 /// Never is a placeholder to ensure we don't return any errors
 #[derive(Error, Debug)]
